@@ -2,6 +2,7 @@ from cms.models import CMSPlugin
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 from django.conf import settings
+from cms.utils.compat.dj import python_2_unicode_compatible
 
 if hasattr(settings, "COLUMN_WIDTH_CHOICES"):
     WIDTH_CHOICES = settings.COLUMN_WIDTH_CHOICES
@@ -16,14 +17,16 @@ else:
         ('100%', _('100%')),
     )
 
+@python_2_unicode_compatible
 class MultiColumns(CMSPlugin):
     """
     A plugin that has sub Column classes
     """
-    def __unicode__(self):
+    def __str__(self):
         return _(u"%s columns") % self.cmsplugin_set.all().count()
 
 
+@python_2_unicode_compatible
 class Column(CMSPlugin):
     """
     A Column for the MultiColumns Plugin
@@ -31,6 +34,6 @@ class Column(CMSPlugin):
 
     width = models.CharField(_("width"), choices=WIDTH_CHOICES, default=WIDTH_CHOICES[0][0], max_length=50)
 
-    def __unicode__(self):
+    def __str__(self):
         return u"%s" % self.get_width_display()
 
